@@ -3,9 +3,11 @@
 # `make test'. After `make install' it should work as `perl test.pl'
 
 use strict;
-use Test::Simple tests => 34;
+use warnings;
+use Test::Simple tests => 35;
+use ExtUtils::MakeMaker qw(prompt);
 
-my $NUM_TESTS = 34;
+my $NUM_TESTS = 35;
 
 use Cisco::Management;
 ok(1, "Loading Module"); # If we made it this far, we're ok.
@@ -25,9 +27,7 @@ print <<STOP;
 
 STOP
 
-print "Router (hostname or IP address)  : ";
-my $router = <STDIN>;
-chomp $router;
+my $router = prompt("Router (hostname or IP address)  : ", '');
 
 if ($router eq '') {
     for (2..$NUM_TESTS) {
@@ -36,9 +36,7 @@ if ($router eq '') {
     exit
 }
 
-print "SNMP read/write Community string : ";
-my $community = <STDIN>;
-chomp $community;
+my $community = prompt("SNMP read/write Community string : ", '');
 
 if ($community eq '') {
     for (2..$NUM_TESTS) {
@@ -110,7 +108,7 @@ my $error;
         ok(0, "Interface (admin up bad range)")
     } else {
         $error = $cm->error;
-        ok($error eq 'Incorrect range format', "Interface (admin up bad range)")
+        ok($error eq "Invalid range format `100000 to 100002'", "Interface (admin up bad range)")
     }
 
 # Interface Info
@@ -311,7 +309,18 @@ my $error;
         ok($sysinfo->system_info_osversion   =~ /\d+/, "System Info (version)");
     } else {
         $error = $cm->error;
-        ok(0, "System Info () [$error]")
+        ok(0, "System Info () [$error]");
+        for (1..8) {
+            ok(0, "System Info ()")
+        }
+    }
+
+    # Get system inventory
+    if (defined(my $inventory = $cm->system_inventory())) {
+        ok($inventory->[0]->{Name} ne '', "System Inventory");
+    } else {
+        $error = $cm->error;
+        ok(0, "System Inventory () [$error]")
     }
 
 # END
